==========
ray-optics
==========

Installation
------------

To install *rayoptics* using pip, use

.. code::

    > pip install rayoptics

Alternatively, *rayoptics* can be installed from the conda-forge channel using conda

.. code::

   > conda install rayoptics --channel conda-forge

Documentation
-------------

The documentation for *ray-optics* is hosted at `Read the Docs <https://ray-optics.readthedocs.io>`_

Tools for image forming optical design and analysis
---------------------------------------------------

RayOptics is a Python geometrical optics and image forming optics library. It provides a geometric ray tracing foundation for the analysis of image forming and coherent optical systems. A number of standard geometrical analysis options such as transverse ray and wavefront aberration analysis are provided on this base. Paraxial layout of optical systems is also supported by y-ybar diagrams and graphical editing of paraxial rays in lens layout views. Import of Zemax .zmx and CODEV .seq files is supported. RayOptics can be used in Python scripts, the Python and IPython shells, the Jupyter notebook, and a Qt-based graphical user interface application.

Note
----

This project has been set up using PyScaffold 3.1. For details and usage information on PyScaffold see https://pyscaffold.org/.
